Creates a blank cohortsLoad.csv template file in the specified folder with proper column structure.
Usage
createBlankCohortsLoadFile(
cohortsFolderPath = here::here("inputs/cohorts"),
openFile = TRUE
)Creates a blank cohortsLoad.csv template file in the specified folder with proper column structure.
createBlankCohortsLoadFile(
cohortsFolderPath = here::here("inputs/cohorts"),
openFile = TRUE
)