Opens the secrets file in the user's editor (like usethis::edit_r_environ()).
If the file doesn't exist, creates a minimal skeleton with just a header comment,
then opens it for editing.
Opens the secrets file in the user's editor (like usethis::edit_r_environ()).
If the file doesn't exist, creates a minimal skeleton with just a header comment,
then opens it for editing.