Skip to contents

use this function if there is not a dbms connection for the study such as using a proprietary tool for the analysis

Usage

placeHolderExecOptions()

Value

A ExecOptions R6 class with the execOptions