Usage
setContributor(name, email, role)
Arguments
- name
the name of the contributor as a character string
- email
the email of the contributor as a character string
- role
the role of the contirbutor as a character string
Value
A ContributorLine R6 class with the contributor info