ConceptSetDef R6 Class
ConceptSetDef R6 Class
Details
An R6 class that stores key information about OHDSI CIRCE concept sets that need to be managed in a study.
The ConceptSetDef class manages concept set metadata, JSON definitions, and domain information. Upon initialization, it loads and validates concept set definitions from CIRCE JSON files, creates a hash to uniquely identify the generated JSON, and stores domain and source concept information.
Active bindings
labelcharacter to set the label to. If missing, returns the current label.
tagslist of the values to set the tags to. If missing, returns the current tags.
Methods
Method new()
Initialize a new ConceptSetDef
Usage
ConceptSetDef$new(label, tags = list(), filePath, domain = "init")Arguments
labelCharacter. The common name of the concept set.
tagsList. A named list of tags that give metadata about the concept set.
filePathCharacter. Path to the concept set JSON file in inputs/conceptSet folder.
domainCharacter. The OMOP CDM clinical domain for this concept set. Valid values: "drug_exposure", "condition_occurrence", "measurement", "procedure", "observation", "device_exposure", "visit_occurrence", "init". Get the file path
sourceCodeLogical. Whether the concept set uses source concepts (TRUE) or standard concepts (FALSE).