An R6 class to define an ExecutionSettings object
Active bindings
cdmDatabaseSchemathe schema containing the OMOP CDM
workDatabaseSchemathe schema containing the cohort table
tempEmulationSchemathe schema needed for temp tables
cohortTablethe table containing the cohorts
databaseNamethe name of the source data of the cdm
Methods
Method new()
Usage
ExecutionSettings$new(
connectionDetails = NULL,
connection = NULL,
cdmDatabaseSchema = NULL,
workDatabaseSchema = NULL,
tempEmulationSchema = NULL,
cohortTable = NULL,
databaseName = NULL
)Arguments
connectionDetailsa connectionDetails object
connectiona connection to a dbms
cdmDatabaseSchemaThe schema of the OMOP CDM database
workDatabaseSchemaThe schema to which results will be written
tempEmulationSchemaSome database platforms like Oracle and Snowflake do not truly support temp tables. To emulate temp tables, provide a schema with write privileges where temp tables can be created.
cohortTableThe name of the table where the cohort(s) are stored
databaseNameA human-readable name for the OMOP CDM database
Method connect()
Connect to DBMS using connectionDetails
Method disconnect()
Disconnect from DBMS
Method getConnection()
Retrieve the active connection object