Appends a new config block to a config.yml file that was
previously generated by initUlyssesRepo(). Useful for adding
additional databases after the initial repo setup without needing
to re-initialize the project.
Usage
addBlock(
configBlock,
configFilePath = here::here("config.yml"),
overwrite = FALSE
)Arguments
- configBlock
A DbConfigBlock R6 object created via
makeBlock().- configFilePath
Character. Path to the config.yml file. Defaults to
config.ymlin the working directory.- overwrite
Logical. If TRUE and a block with the same name already exists in config.yml, it will be replaced. Default FALSE (error on duplicate).