Lists all credentials stored in the "picard" keyring service with their actual values, organized by database servers and Atlas. Useful for verifying that setup functions correctly stored credentials and debugging resolution issues.
Lists all credentials stored in the "picard" keyring service with their actual values, organized by database servers and Atlas. Useful for verifying that setup functions correctly stored credentials and debugging resolution issues.