Updates the version across the project including config.yml, README.md, and NEWS.md. Prompts the user to document changes from the pipeline run as bullet points which are added to NEWS.
Usage
updateStudyVersion(versionNumber, projectPath = here::here())